@@ -24,6 +24,7 @@
 #include "backends/basepersonsdatasource.h"
 #include "backends/contactmonitor.h"
 #include "backends/abstractcontact.h"
+#include "backends/abstracteditablecontact.h"
 
 #include <QUrl>
 #include "kpeople_debug.h"
@@ -67,7 +68,7 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
     }
 
     QMap<QString, AbstractContact::Ptr> contacts;
-    Q_FOREACH (const QString &contactUri, d->contactUris) {
+    for (const QString &contactUri : qAsConst(d->contactUris)) {
         //load the correct data source for this contact ID
         const QString sourceId = contactUri.left(contactUri.indexOf(QStringLiteral("://")));
         Q_ASSERT(!sourceId.isEmpty());
@@ -121,7 +122,9 @@ void PersonData::onContactChanged()
     Q_D(PersonData);
 
     ContactMonitor *watcher = qobject_cast<ContactMonitor *>(sender());
-    if (d->metaContact.contactUris().contains(watcher->contactUri())) {
+    if (!watcher->contact()) {
+        d->metaContact.removeContact(watcher->contactUri());
+    } else if (d->metaContact.contactUris().contains(watcher->contactUri())) {
 #ifdef __GNUC__
 #warning probably not needed anymore
 #endif
@@ -144,7 +147,7 @@ QPixmap PersonData::photo() const
     }
 
     if (avatar.isNull()) {
-        static QString defaultAvatar = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kpeople/dummy_avatar.png"));
+        static QString defaultAvatar = QStringLiteral(":/org.kde.kpeople/pixmaps/dummy_avatar.png");
         avatar = QPixmap(defaultAvatar);
     }
     return avatar;
@@ -155,6 +158,14 @@ QVariant PersonData::contactCustomProperty(const QString &key) const
     return d->metaContact.personAddressee()->customProperty(key);
 }
 
+bool KPeople::PersonData::setContactCustomProperty(const QString& key, const QVariant& value)
+{
+    Q_D(PersonData);
+    auto contact = dynamic_cast<AbstractEditableContact*>(d->metaContact.personAddressee().data());
+
+    return contact && contact->setCustomProperty(key, value);
+}
+
 QString PersonData::presenceIconName() const
 {
     QString contactPresence = contactCustomProperty(QStringLiteral("telepathy-presence")).toString();
@@ -185,9 +196,9 @@ QStringList PersonData::groups() const
 {
 //     We might want to cache it eventually?
 
-    QVariantList groups = contactCustomProperty(AbstractContact::GroupsProperty).toList();
+    const QVariantList groups = contactCustomProperty(AbstractContact::GroupsProperty).toList();
     QStringList ret;
-    Q_FOREACH (const QVariant &g, groups) {
+    for (const QVariant &g : groups) {
         Q_ASSERT(g.canConvert<QString>());
         ret += g.toString();
     }
@@ -197,9 +208,9 @@ QStringList PersonData::groups() const
 
 QStringList PersonData::allEmails() const
 {
-    QVariantList emails = contactCustomProperty(AbstractContact::AllEmailsProperty).toList();
+    const QVariantList emails = contactCustomProperty(AbstractContact::AllEmailsProperty).toList();
     QStringList ret;
-    Q_FOREACH (const QVariant &e, emails) {
+    for (const QVariant &e : emails) {
         Q_ASSERT(e.canConvert<QString>());
         ret += e.toString();
     }
@@ -207,3 +218,8 @@ QStringList PersonData::allEmails() const
     return ret;
 }
 
+bool KPeople::PersonData::isEditable() const
+{
+    Q_D(const PersonData);
+    return dynamic_cast<const AbstractEditableContact*>(d->metaContact.personAddressee().constData());
+}
